/*
 * synergy -- mouse and keyboard sharing utility
 * Copyright (C) 2004 Chris Schoeneman
 * 
 * This package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * found in the file COPYING that should have accompanied this file.
 * 
 * This package is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#include "Version.h"

const char* kApplication = "Synergy";
const char* kCopyright   = "Copyright (C) 2002 Chris Schoeneman";
const char* kContact     = "Chris Schoeneman, crs23@bigfoot.com";
const char* kWebsite     = "http://synergy2.sourceforge.net/";
const char* kVersion	 = VERSION;
const char* kAppVersion  = "Synergy " VERSION;
